@@ -3,8 +3,10 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 from collections import Hashable
 from functools import partial
 import logging
+import os
 from os.path import dirname
 import re
+import subprocess
 import sys
 import threading
 
@@ -77,16 +79,25 @@ def path_identity(path):
 
 
 def win_path_to_unix(path, root_prefix=""):
-    """Convert a path or ;-separated string of paths into a unix representation
-
-    Does not add cygdrive.  If you need that, set root_prefix to "/cygdrive"
-    """
-    path_re = '(?<![:/^a-zA-Z])([a-zA-Z]:[\/\\\\]+(?:[^:*?"<>|]+[\/\\\\]+)*[^:*?"<>|;\/\\\\]+?(?![a-zA-Z]:))'  # noqa
-
-    def _translation(found_path):
-        found = found_path.group(1).replace("\\", "/").replace(":", "").replace("//", "/")
-        return root_prefix + "/" + found
-    path = re.sub(path_re, _translation, path).replace(";/", ":/")
+    # If the user wishes to drive conda from MSYS2 itself while also having
+    # msys2 packages in their environment this allows the path conversion to
+    # happen relative to the actual shell. The onus is on the user to set
+    # CYGPATH to e.g. /usr/bin/cygpath.exe (this will be translated to e.g.
+    # (C:\msys32\usr\bin\cygpath.exe by MSYS2) to ensure this one is used.
+    cygpath = os.environ.get('CYGPATH', 'cygpath.exe')
+    if not path:
+        return ''
+    try:
+        path = subprocess.check_output([cygpath, '-up', path]).decode('ascii').split('\n')[0]
+    except Exception as e:
+        log.debug('%r' % e, exc_info=True)
+        # Convert a path or ;-separated string of paths into a unix representation
+        # Does not add cygdrive.  If you need that, set root_prefix to "/cygdrive"
+        def _translation(found_path):  # NOQA
+            found = found_path.group(1).replace("\\", "/").replace(":", "").replace("//", "/")
+            return root_prefix + "/" + found
+        path_re = '(?<![:/^a-zA-Z])([a-zA-Z]:[\/\\\\]+(?:[^:*?"<>|]+[\/\\\\]+)*[^:*?"<>|;\/\\\\]+?(?![a-zA-Z]:))'  # noqa
+        path = re.sub(path_re, _translation, path).replace(";/", ":/")
     return path
 
 
